==> igniteui-react-core-16.16.1.tgz: package/esm5/lib/StockChangedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { StockChangedEventArgsDescription } from "./StockChangedEventArgsDescription";
/**
 * @hidden
 */
var StockChangedEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(StockChangedEventArgsDescriptionMetadata, _super);
    function StockChangedEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    StockChangedEventArgsDescriptionMetadata.b = function (a) {
        if (StockChangedEventArgsDescriptionMetadata.a == null) {
            StockChangedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            StockChangedEventArgsDescriptionMetadata.c(StockChangedEventArgsDescriptionMetadata.a);
        }
        if (a.g(StockChangedEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.s(StockChangedEventArgsDescriptionMetadata.a);
    };
    StockChangedEventArgsDescriptionMetadata.c = function (a) {
        a.item("AddedSymbols", "Array:string");
        a.item("RemovedSymbols", "Array:string");
    };
    StockChangedEventArgsDescriptionMetadata.d = function (a) {
        StockChangedEventArgsDescriptionMetadata.b(a);
        a.u("StockChangedEventArgs", function () { return new StockChangedEventArgsDescription(); });
        a.t("StockChangedEventArgs", StockChangedEventArgsDescriptionMetadata.a);
    };
    StockChangedEventArgsDescriptionMetadata.$t = markType(StockChangedEventArgsDescriptionMetadata, 'StockChangedEventArgsDescriptionMetadata');
    StockChangedEventArgsDescriptionMetadata.a = null;
    return StockChangedEventArgsDescriptionMetadata;
}(Base));
export { StockChangedEventArgsDescriptionMetadata };

==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/StockChangedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { StockChangedEventArgsDescription } from "./StockChangedEventArgsDescription";
/**
 * @hidden
 */
var StockChangedEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(StockChangedEventArgsDescriptionMetadata, _super);
    function StockChangedEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    StockChangedEventArgsDescriptionMetadata.b = function (a) {
        if (StockChangedEventArgsDescriptionMetadata.a == null) {
            StockChangedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            StockChangedEventArgsDescriptionMetadata.c(StockChangedEventArgsDescriptionMetadata.a);
        }
        if (a.j(StockChangedEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.y(StockChangedEventArgsDescriptionMetadata.a);
    };
    StockChangedEventArgsDescriptionMetadata.c = function (a) {
        a.item("AddedSymbols", "Array:string");
        a.item("RemovedSymbols", "Array:string");
    };
    StockChangedEventArgsDescriptionMetadata.d = function (a) {
        StockChangedEventArgsDescriptionMetadata.b(a);
        a.aa("StockChangedEventArgs", function () { return new StockChangedEventArgsDescription(); });
        a.z("StockChangedEventArgs", StockChangedEventArgsDescriptionMetadata.a);
    };
    StockChangedEventArgsDescriptionMetadata.$t = markType(StockChangedEventArgsDescriptionMetadata, 'StockChangedEventArgsDescriptionMetadata');
    StockChangedEventArgsDescriptionMetadata.a = null;
    return StockChangedEventArgsDescriptionMetadata;
}(Base));
export { StockChangedEventArgsDescriptionMetadata };
